package gotowe.p06_funkcje.przyklady;

import javax.swing.JOptionPane;

public class ProgramGeometrycznyOkienkowy {

    public static void main(String[] args) {
        String[] figury = { "kwadrat", "prostokąt", "koło" };
        String figura = (String)JOptionPane.showInputDialog(
                null,
                "Wybierz rodzaj figury",
                "Wybór",
                JOptionPane.QUESTION_MESSAGE,
                null,
                figury,
                null);

        switch(figura) {
        case "kwadrat" -> {
            double a = Double.parseDouble(JOptionPane.showInputDialog("Podaj długość boku:"));
            double pole = Geometria.poleKwadratu(a);
            double obwod = Geometria.obwodKwadratu(a);
            JOptionPane.showMessageDialog(null, "Pole: " + pole + "\nObwód: " + obwod);
        }

        case "prostokąt" -> {
            double a = Double.parseDouble(JOptionPane.showInputDialog("Podaj długość 1. boku:"));
            double b = Double.parseDouble(JOptionPane.showInputDialog("Podaj długość 2. boku:"));
            double pole = Geometria.poleProstokata(a, b);
            double obwod = Geometria.obwodProstokata(a, b);
            JOptionPane.showMessageDialog(null, "Pole: " + pole + "\nObwód: " + obwod);
        }
        case "koło" -> {
            double r = Double.parseDouble(JOptionPane.showInputDialog("Podaj promień koła:"));
            double pole = Geometria.poleKola(r);
            double obwod = Geometria.obwodKola(r);
            JOptionPane.showMessageDialog(null, "Pole: " + pole + "\nObwód: " + obwod);
        }
        }
    }

}
